@@ -20,16 +20,22 @@
 //! - Migrating will often be as easy as dropping the `_lab` suffix from imports when migrating.
 
 mod acceptable;
+mod body_extractor_fold;
+mod body_hash;
 mod buffered_serializing_stream;
 mod channel_body;
 mod csv;
 mod display_stream;
+mod hmac;
+mod html;
 mod json;
 mod lazy_data;
 mod middleware_from_fn;
 mod ndjson;
 mod query;
 mod redirect;
+mod redirect_to_https;
+mod redirect_to_www;
 mod spa;
 mod utils;
 
